@@ -20,7 +20,8 @@ sub new {
 sub build_requires {
     return +{
 ##	'Test::More'	=> 0.40,
-	'Test::More'	=> 0.88,	# Because of done_testing().
+##	'Test::More'	=> 0.88,	# Because of done_testing().
+	'Test::More'	=> 0.96,	# Because of subtest()
     };
 }
 
@@ -40,14 +41,17 @@ sub requires {
 	'Getopt::Long'		=> 0,
 	'HTML::Parser'		=> 0,
 	'HTTP::Response'	=> 0,
-	'HTTP::Status'		=> 0,
+	'HTTP::Status'		=> 6.03,	# For the teapot status
 	'IO::File'		=> 0,
+	'JSON'			=> 0,	# For Space Track v2
+	'List::Util'		=> 0,	# For Space Track v2 FILE tracking
 	'LWP::UserAgent'	=> 0,
 	'LWP::Protocol::https'	=> 0,	# Space track needs as of 11-Apr-2011
 	'POSIX'			=> 0,
 	'Scalar::Util'		=> 1.07,	# for openhandle.
 	'Text::ParseWords'	=> 0,
 	'Time::Local'		=> 0,
+	'URI::Escape'		=> 0,	# For Space Track v2
 	'constant'		=> 0,
 	'strict'		=> 0,
 	'warnings'		=> 0,
@@ -73,9 +77,9 @@ My::Module::Meta - Information needed to build Astro::SpaceTrack
  use lib qw{ inc };
  use My::Module::Meta;
  my $meta = My::Module::Meta->new();
- use YAML;
- print "Required modules:\n", Dump(
-     $meta->requires() );
+ use JSON;
+ print "Required modules:\n", to_json(
+     $meta->requires(), { pretty => 1 } );
 
 =head1 DETAILS
 
@@ -96,8 +100,8 @@ This method instantiates the class.
 
 =head2 build_requires
 
- use YAML;
- print Dump( $meta->build_requires() );
+ use JSON;
+ print to_json( $meta->build_requires(), { pretty => 1 } );
 
 This method computes and returns a reference to a hash describing the
 modules required to build the C<Astro::Coord::ECI> package, suitable for
@@ -117,8 +121,8 @@ C<MAKING_MODULE_DISTRIBUTION> at the time the object was instantiated.
 
 =head2 requires
 
- use YAML;
- print Dump( $meta->requires() );
+ use JSON;
+ print to_json( $meta->requires(), { pretty => 1 } );
 
 This method computes and returns a reference to a hash describing
 the modules required to run the C<App::Satpass2> package, suitable for
